@@ -50,24 +50,22 @@ import os.path
 import optparse
 import re
 import datetime
-import glob
-import locale
 import ConfigParser
 import gobject
 import gtk
 import pango
 import libxml2
 import mobius.application
+import mobius.config
 import mobius.decoder.aol_feedbag
 import mobius.decoder.icqlite_xml
 import mobius.decoder.icq2003b_uin
 import mobius.ui.base_window
+import mobius.ui.manager
 
-#locale.setlocale (locale.LC_ALL, 'pt_BR')
 MESSAGE_EXP = re.compile ('.*?/ICQLite/HistoryDB/([0-9]+)/([0-9]+)/.*')
 BASE_DATETIME = datetime.datetime (1970, 1, 1)
 (MSG_TOGGLE, MSG_TIME, MSG_FROM, MSG_TO, MSG_TEXT, MSG_OBJ) = range (6)
-VERSION='0.2.0.1'
 
 #-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief Account
@@ -479,7 +477,7 @@ class MobiusICQViewer (mobius.ui.base_window.MobiusBaseWindow):
   # @brief Set title
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def set_title (self, subtitle=None):
-    title = 'Mobius ICQ Viewer v%s' % VERSION
+    title = 'Mobius ICQ Viewer v%s' % mobius.config.APP_VERSION
     if subtitle:
       title += ' [%s]' % subtitle
 
@@ -570,7 +568,7 @@ class MobiusICQBrowser (gtk.Window):
     gtk.Window.__init__ (self)
     self.connect ('delete-event', self.on_close_window)
     self.set_default_size (600, 400)
-    self.set_title ('Mobius ICQ Viewer v%s' % VERSION)
+    self.set_title ('Mobius ICQ Viewer v%s' % mobius.config.APP_VERSION)
 
     # accel_group
     accel_group = gtk.AccelGroup ()
@@ -717,13 +715,7 @@ class MobiusICQBrowser (gtk.Window):
   # @brief call 'about' dialog
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= 
   def on_help_about (self, widget, *args):
-    dialog = gtk.AboutDialog ()
-    dialog.set_name ('Mobius Forensic Toolkit')
-    dialog.set_version (VERSION)
-    dialog.set_copyright (u'Copyright \u00a9 2007 Eduardo Aguiar'.encode ('utf-8'))
-    dialog.set_license ('GNU Public License')
-    dialog.set_authors (['Eduardo Aguiar <aguiar.users@sourceforge.net>'])
-    dialog.set_comments ('Open-source forensic tool')
+    dialog = mobius.ui.about_dialog.Dialog ()
     dialog.run ()
     dialog.destroy ()
 
@@ -762,26 +754,20 @@ class MobiusICQBrowser (gtk.Window):
       window.populate (account)
       window.show ()
 
-  # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  # @brief Flush interface
-  # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  def flush_interface (self):
-    while gtk.events_pending ():
-      gtk.main_iteration ()
-
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief Scan ICQ directory
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def scan (self, path):
-    self.flush_interface ()
+    ui_manager = mobius.ui.manager.UIManager (self)
+    ui_manager.flush ()
     pos = len (path) + 1
     model = ICQModel ()
 
     # scan directory
     for root, dirs, files in os.walk (path):
       self.status_label.set_text ('Scanning: %s' % root[pos:])
-      self.flush_interface ()
-      
+      ui_manager.flush ()
+
       for filename in files:
         fullpath = os.path.join (root, filename)
         extension = os.path.splitext (filename)[1][1:]
